#pragma once

#include "QuantumCircuitElement.h"

class AbstractQuantumWire : public QuantumCircuitElement
{
public:
    enum class WireType
    {
        QUANTUM,
        CLASSICAL
    };

    virtual ~AbstractQuantumWire() = default;

    virtual WireType getWireType() const = 0;
};

class QuantumWire : public AbstractQuantumWire
{
public:
    QuantumWire(QuantumCircuitElement* input, QuantumCircuitElement* output);

    QuantumCircuitElement* getInput() const;
    QuantumCircuitElement* getOutput() const;

    Type getType() const override;
    WireType getWireType() const override;
private:
    QuantumCircuitElement* mInput{ nullptr };
    QuantumCircuitElement* mOutput{ nullptr };
};
using QuantumWirePtr = std::unique_ptr<QuantumWire>;

class ClassicalWire : public AbstractQuantumWire
{
public:
    WireType getWireType() const override
    {
        return WireType::CLASSICAL;
    }
};